Module blaxel.core.sandbox.client.models.directory
==================================================

Classes
-------

`Directory(files: list['File'], name: str, path: str, subdirectories: list['Subdirectory'])`
:   Attributes:
        files (list['File']):
        name (str):
        path (str):
        subdirectories (list['Subdirectory']): @name Subdirectories
    
    Method generated by attrs for class Directory.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `files`
    :

    `name`
    :

    `path`
    :

    `subdirectories`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :